@@ -15,6 +15,7 @@
 
 import os
 import datetime
+from django.core.exceptions import SuspiciousOperation
 
 if __name__ == "__main__":
     # run all unittest directly
@@ -147,30 +148,32 @@ class BlogPluginTestCase(basetest.BaseLanguageTestCase):
         return self.login_with_permissions(usertype="normal", permissions=(ADD_PERMISSION,))
 
 
+class BlogPluginAnonymousTestCase(BlogPluginTestCase):
+    def setUp(self):
+        cache.clear()
 
-class BlogPluginAnonymousTest(BlogPluginTestCase):
+        from pylucid_project.apps.pylucid.preference_forms import SystemPreferencesForm
+        self.system_pref_form = SystemPreferencesForm()
+        self.system_preferences = self.system_pref_form.get_preferences()
+        self.system_preferences["message_level_anonymous"] = message_constants.DEBUG
+        self.system_pref_form.save()
+
+        DEBUG_LANG_FILTER = True
+        settings.PYLUCID.I18N_DEBUG = True
+
+        self.pref_form = BlogPrefForm()
+
+    def _set_language_filter(self, language_filter):
+        self.pref_form["language_filter"] = language_filter
+        self.pref_form.save()
+
+
+class BlogPluginAnonymousTest(BlogPluginAnonymousTestCase):
     """
     ALL_LANGUAGES - "Don't filter by languages. Allways display all blog entries."
     PREFERED_LANGUAGES - "Filter by client prefered languages (set in browser and send by HTTP_ACCEPT_LANGUAGE header)"
     CURRENT_LANGUAGE - "Display only blog entries in current language (select on the page)"
     """
-
-    def setUp(self):
-        cache.clear()
-
-        from pylucid_project.apps.pylucid.preference_forms import SystemPreferencesForm
-        system_preferences = SystemPreferencesForm()
-        system_preferences["message_level_anonymous"] = message_constants.DEBUG
-        system_preferences.save()
-        DEBUG_LANG_FILTER = True
-        settings.PYLUCID.I18N_DEBUG = True
-
-
-    def _set_language_filter(self, language_filter):
-        self.pref_form = BlogPrefForm()
-        self.pref_form["language_filter"] = language_filter
-        self.pref_form.save()
-
     def test_summary_en_all_languages(self):
         self._set_language_filter(BlogPrefForm.ALL_LANGUAGES)
 
@@ -219,6 +222,42 @@ class BlogPluginAnonymousTest(BlogPluginTestCase):
             must_not_contain=('<meta name="robots" content="index,follow" />',)
         )
 
+    def test_same_slug_en(self):
+        self._set_language_filter(BlogPrefForm.ALL_LANGUAGES)
+
+        lang_code = self.default_language.code
+        url = "%s%s/same-slug/" % (SUMMARY_URL % lang_code, TEST_DATE)
+
+        response = self.client.get(url,
+            HTTP_ACCEPT_LANGUAGE=self.default_language.code,
+        )
+        self.assertBlogPage(response, self.default_language,
+            must_contain=(
+                '<html lang="en">',
+                "Same headline in german and english",
+                "<p>4. <strong>blog article</strong> in <i>english</i>!</p>",
+            ),
+            must_not_contain=("Traceback",),
+        )
+
+    def test_same_slug_de(self):
+        self._set_language_filter(BlogPrefForm.ALL_LANGUAGES)
+
+        lang_code = self.other_language.code
+        url = "%s%s/same-slug/" % (SUMMARY_URL % lang_code, TEST_DATE)
+
+        response = self.client.get(url,
+            HTTP_ACCEPT_LANGUAGE=self.other_language.code,
+        )
+        self.assertBlogPage(response, self.other_language,
+            must_contain=(
+                '<html lang="de">',
+                "Same headline in german and english",
+                "<p>4. <strong>Blog Artikel</strong> in <i>deutsch</i>!</p>",
+            ),
+            must_not_contain=("Traceback",),
+        )
+
 #    def test_summary_en_prefered_languages(self):
 #        self._set_language_filter(BlogPrefForm.PREFERED_LANGUAGES)
 #
@@ -304,6 +343,105 @@ class BlogPluginAnonymousTest(BlogPluginTestCase):
         self._test_rss_feed(self.other_language)
 '''
 
+class BlogPluginTagsTest(BlogPluginAnonymousTestCase):
+    """
+    ALL_LANGUAGES - "Don't filter by languages. Allways display all blog entries."
+    PREFERED_LANGUAGES - "Filter by client prefered languages (set in browser and send by HTTP_ACCEPT_LANGUAGE header)"
+    CURRENT_LANGUAGE - "Display only blog entries in current language (select on the page)"
+    """
+
+    def setUp(self):
+        super(BlogPluginTagsTest, self).setUp()
+
+        self.pref_form["max_tag_count"] = 2 # Allow only two tag filters
+        self.pref_form.save()
+        self._set_language_filter(BlogPrefForm.ALL_LANGUAGES)
+
+    def test_canonical_url(self):
+        url = TAG_URL = "/%s/blog/tags/%s/" % (self.default_language.code,
+            "/".join(["sharedtag", "second_tag"])
+        )
+        response = self.client.get(url,
+            HTTP_ACCEPT_LANGUAGE=self.default_language.code,
+        )
+        self.assertRedirect(response,
+            # and not ...estserver/en/blog/tags/sharedtag/second_tag/ ;)
+            url="http://testserver/en/blog/tags/second_tag/sharedtag/",
+            status_code=301 # permanent redirect
+        )
+
+    def test_one_tag_filter(self):
+        # With one tag filter, other tags has "add-link"
+        url = TAG_URL = "/%s/blog/tags/%s/" % (self.default_language.code, "sharedtag")
+        response = self.client.get(url,
+            HTTP_ACCEPT_LANGUAGE=self.default_language.code,
+        )
+        self.assertBlogPage(response, self.default_language,
+            must_contain=('Your personal weblog.',
+                '<strong style="font-size:2em;">sharedtag</strong>', # current tag filter
+                'rel="nofollow">[+]</a>', # link to add tag filter
+                'rel="nofollow">second_tag</a>', # Other tag filter
+            ),
+            must_not_contain=('Traceback',)
+        )
+
+    def test_reached_tag_filters(self):
+        # With two tags, the max number of filters is reached -> No "add-link"
+        url = TAG_URL = "/%s/blog/tags/%s/" % (self.default_language.code,
+            "/".join(["second_tag", "sharedtag"])
+        )
+        response = self.client.get(url,
+            HTTP_ACCEPT_LANGUAGE=self.default_language.code,
+        )
+        self.assertBlogPage(response, self.default_language,
+            must_contain=('Your personal weblog.',
+                '<strong style="font-size:1em;">second_tag</strong>', # current tag filter 1
+                '<strong style="font-size:1em;">sharedtag</strong>', # current tag filter 2
+                'rel="nofollow">english-tag</a>', # Other tag filter
+            ),
+            must_not_contain=('Traceback',
+                'rel="nofollow">[+]</a>', # link to add tag filter
+            )
+        )
+
+    def test_too_mush_tags_filters(self):
+        # With three tags are one to murch -> raise 404
+        url = TAG_URL = "/%s/blog/tags/%s/" % (self.default_language.code,
+            "/".join(["second_tag", "sharedtag", "english-tag"])
+        )
+        response = self.client.get(url,
+            HTTP_ACCEPT_LANGUAGE=self.default_language.code,
+        )
+        self.failUnlessEqual(response.status_code, 404)
+
+    def _request_with_too_much_tags(self):
+        url = TAG_URL = "/%s/blog/tags/%s/" % (self.default_language.code,
+            "/".join(["second_tag", "sharedtag", "english-tag", "too_mutch"])
+        )
+        response = self.client.get(url,
+            HTTP_ACCEPT_LANGUAGE=self.default_language.code,
+        )
+        return response
+
+    def test_too_mush_tags_filters_and_ban(self):
+        ban_count = int(self.system_preferences["ban_count"])
+
+        for i in xrange(ban_count):
+            # With four tags are two to murch -> raise SuspiciousOperation and log this
+            response = self._request_with_too_much_tags()
+            self.failUnlessEqual(response.status_code, 404)
+
+        # We are banned after 'ban_count' bad requests -> Get 403 Forbidden
+        response = self._request_with_too_much_tags()
+        self.failUnlessEqual(response.status_code, 403)
+
+        # Important: We must remove "us" from ban list, otherwise other unittests
+        # will failed ;)
+        from pylucid_project.apps.pylucid.models import BanEntry
+        BanEntry.objects.all().delete()
+
+        # Test if we are not banned anymore:
+        self.test_one_tag_filter()
 
 
 class BlogPluginTest(BlogPluginTestCase):
@@ -700,6 +838,7 @@ if __name__ == "__main__":
     tests = __file__
 #    tests = "pylucid_plugins.blog.tests.BlogPluginCsrfTest"
 #    tests = "pylucid_plugins.blog.tests.BlogPluginAnonymousTest"
+#    tests = "pylucid_plugins.blog.tests.BlogPluginTagsTest"
 #    tests = "pylucid_plugins.blog.tests.BlogLanguageFilterTest"
 #    tests = "pylucid_plugins.blog.tests.BlogPluginTest"
 #    tests = "pylucid_plugins.blog.tests.BlogPluginTest.test_create_csrf_check"
